autowisp.tests package — AutoWISP documentation

# autowisp.tests package

## Class Inheritance Diagram

Autowisp unit-test init.

class autowisp.tests.AutoWISPTestCase(methodName='runTest')

  Bases: `FloatTestCase`

  Base class for AutoWISP tests.

  get_inputs(inputs)

    Get the input files for the test step and return what to clean up.

  run_step(command)

    Run a calibration step and check the return code.

  setUp()

    Make sure the data to compare against is defined.

  classmethod set_test_directory(test_dirname, processing_dirname, failed_test_dirname)

    Set the directory where data to test against is located.

  successful_test = False
  tearDown()

    Remove the processing directory.

## Submodules

- autowisp.tests.fits_test_case module
  - Class Inheritance Diagram
  - `FITSTestCase`
    - `FITSTestCase.assert_fits_match()`
- autowisp.tests.get_test_data module
  - Class Inheritance Diagram
  - `download_zip()`
  - `get_test_data()`
- autowisp.tests.h5_test_case module
  - Class Inheritance Diagram
  - `H5TestCase`
    - `H5TestCase.assert_groups_match()`
    - `H5TestCase.run_step_test()`
- autowisp.tests.test_calibrate module
  - Class Inheritance Diagram
  - `TestCalibrate`
    - `TestCalibrate._test_calibration()`
    - `TestCalibrate.test_bias_calibration()`
    - `TestCalibrate.test_dark_calibration()`
    - `TestCalibrate.test_flat_calibration()`
    - `TestCalibrate.test_object_calibration()`
- autowisp.tests.test_create_lightcurves module
  - Class Inheritance Diagram
  - `TestCreateLightcurves`
    - `TestCreateLightcurves.is_postprocessing()`
    - `TestCreateLightcurves.test_create_lightcurves()`
- autowisp.tests.test_detrending_stat module
  - Class Inheritance Diagram
  - `TestDetrendingStat`
    - `TestDetrendingStat.run_test()`
    - `TestDetrendingStat.test_generate_epd_statistics()`
    - `TestDetrendingStat.test_generate_tfa_statistics()`
- autowisp.tests.test_epd module
  - Class Inheritance Diagram
  - `TestEPD`
    - `TestEPD.test_epd()`
- autowisp.tests.test_find_stars module
  - Class Inheritance Diagram
  - `TestFindStars`
    - `TestFindStars.test_find_stars()`
- autowisp.tests.test_fit_magnitudes module
  - Class Inheritance Diagram
  - `TestFitMagnitudes`
    - `TestFitMagnitudes.test_fit_magnitudes()`
- autowisp.tests.test_fit_source_extracted_psf_map module
  - Class Inheritance Diagram
  - `TestFitSourceExtractedPSFMap`
    - `TestFitSourceExtractedPSFMap.test_fit_source_extracted_psf_map()`
- autowisp.tests.test_fit_star_shape module
  - Class Inheritance Diagram
  - `TestFitStarShape`
    - `TestFitStarShape.test_fit_star_shape()`
- autowisp.tests.test_measure_aperture_photometry module
  - Class Inheritance Diagram
  - `TestMeasureAperturePhotometry`
    - `TestMeasureAperturePhotometry.is_magfit()`
    - `TestMeasureAperturePhotometry.test_measure_aperture_photometry()`
- autowisp.tests.test_solve_astrometry module
  - Class Inheritance Diagram
  - `TestSolveAstrometry`
    - `TestSolveAstrometry.test_solve_astrometry()`
- autowisp.tests.test_stack_to_master module
  - Class Inheritance Diagram
  - `TestStackToMaster`
    - `TestStackToMaster._test_stack_to_master()`
    - `TestStackToMaster.test_stack_master_bias()`
    - `TestStackToMaster.test_stack_master_dark()`
    - `TestStackToMaster.test_stack_master_flat()`
- autowisp.tests.test_tfa module
  - Class Inheritance Diagram
  - `TestTFA`
    - `TestTFA.test_tfa()`